#chtEnumerateNoun.py
#a plugin specifically designed for the Chinese language, allowing users to differentiate characters with the same sound.  This is meant to be an enhancement to the existing character description module.
#This plugin limits the verbosity of character descriptions of Chinese characters to one noun at a time.  Sequential calls to the getCharacterDescription function on the same character will speak the list of nouns available in the dictionary, and loops back to the first noun when the list is exhausted.
#Written by Michael Chen <m11chen@gmail.com>

import globalPluginHandler
import config
from config import conf
import characterProcessing


#instantiate a section "chtNounEnumerate" in the config file for storing dynamic information related to this plugin.
confSect = conf.get("chtNounEnumerate")

if not confSect:
	confSect = conf["chtNounEnumerate"] = {}
conf["chtNounEnumerate"]["currentCharacter"] = ""	#Stores the character which had its description spoken last.
conf["chtNounEnumerate"]["count"] = 0	#Stores the number of times the getCharacterDescription function is called on the same character.


def modified_getCharacterDescription(locale,character):
	"""
	This function overides the default getCharacterDescription function.  If the locale is set to a language other than zh_TW, the function returns the same as the default function.
	@param locale: the locale (language[_COUNTRY]) the description should be for.
	@type locale: string
	@param character: the character  who's description should be retreaved.
	@type character: string
	@return:  the found description for the given character.  If the locale is set to zh_TW, it returns a single noun instead of the entire list of nouns found in the locale dictionary.
	@rtype: string
	"""
	l=characterProcessing._charDescLocaleDataMap.fetchLocaleData(locale)
	desc=l.getCharacterDescription(character)

	if locale != "zh_TW":
		return desc

	else:
		c = conf["chtNounEnumerate"]["currentCharacter"]
		currentCount= conf["chtNounEnumerate"]["count"]

		if not desc:
			return character

		else:
			desc=desc.split(u'\u3002')

		if c == character and currentCount< len(desc):
			currentDesc=desc[currentCount]
			conf["chtNounEnumerate"]["count"] = currentCount +1

			if conf["chtNounEnumerate"]["count"] == len(desc):
				conf["chtNounEnumerate"]["count"] = 0

			return currentDesc

		else:
			conf["chtNounEnumerate"]["currentCharacter"] = character
			conf["chtNounEnumerate"]["count"] = 1
			return desc[0]
 

class GlobalPlugin(globalPluginHandler.GlobalPlugin):

	def __init__(self):
		super(GlobalPlugin, self).__init__()
		self._oldGetCharacterDescription = characterProcessing.getCharacterDescription
		characterProcessing.getCharacterDescription= modified_getCharacterDescription

	def terminate(self):
		characterProcessing.getCharacterDescription = self.old_getCharacterDescription
		super(GlobalPlugin, self).terminate()
